summary refs log tree commit diff
path: root/src/libnm-glib-aux/nm-shared-utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libnm-glib-aux/nm-shared-utils.h')
-rw-r--r--src/libnm-glib-aux/nm-shared-utils.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/libnm-glib-aux/nm-shared-utils.h b/src/libnm-glib-aux/nm-shared-utils.h
index d350d32e..ca9feb60 100644
--- a/src/libnm-glib-aux/nm-shared-utils.h
+++ b/src/libnm-glib-aux/nm-shared-utils.h
@@ -154,13 +154,13 @@ typedef enum {
     NM_LINK_TYPE_WIREGUARD,
 #define _NM_LINK_TYPE_SW_LAST NM_LINK_TYPE_WIREGUARD
 
 /* Software types with slaves */
 #define _NM_LINK_TYPE_SW_MASTER_FIRST NM_LINK_TYPE_BRIDGE
     NM_LINK_TYPE_BRIDGE,
     NM_LINK_TYPE_BOND,
     NM_LINK_TYPE_HSR,
     NM_LINK_TYPE_TEAM,
-#define _NM_LINK_TYPE_SW_MASTER_LAST NM_LINK_TYPE_TEAM
+#define _NM_LINK_TYPE_SW_CONTROLLER_LAST NM_LINK_TYPE_TEAM
 
 #define _NM_LINK_TYPE_REAL_LAST NM_LINK_TYPE_TEAM
 
@@ -171,15 +171,16 @@ typedef enum {
 static inline gboolean
 nm_link_type_is_software(NMLinkType link_type)
 {
-    G_STATIC_ASSERT(_NM_LINK_TYPE_SW_LAST + 1 == _NM_LINK_TYPE_SW_MASTER_FIRST);
+    G_STATIC_ASSERT(_NM_LINK_TYPE_SW_LAST + 1 == _NM_LINK_TYPE_SW_CONTROLLER_FIRST);
 
-    return link_type >= _NM_LINK_TYPE_SW_FIRST && link_type <= _NM_LINK_TYPE_SW_MASTER_LAST;
+    return link_type >= _NM_LINK_TYPE_SW_FIRST && link_type <= _NM_LINK_TYPE_SW_CONTROLLER_LAST;
 }
 
 static inline gboolean
-nm_link_type_supports_slaves(NMLinkType link_type)
+nm_link_type_supports_ports(NMLinkType link_type)
 {
-    return link_type >= _NM_LINK_TYPE_SW_MASTER_FIRST && link_type <= _NM_LINK_TYPE_SW_MASTER_LAST;
+    return link_type >= _NM_LINK_TYPE_SW_CONTROLLER_FIRST
+           && link_type <= _NM_LINK_TYPE_SW_CONTROLLER_LAST;
 }
 
 /*****************************************************************************/
@@ -154,13 +154,13 @@ typedef enum {
 #define _NM_LINK_TYPE_SW_LAST NM_LINK_TYPE_WIREGUARD
 
-/* Software types with slaves */
-#define _NM_LINK_TYPE_SW_MASTER_FIRST NM_LINK_TYPE_BRIDGE
+/* Software types with ports */
+#define _NM_LINK_TYPE_SW_CONTROLLER_FIRST NM_LINK_TYPE_BRIDGE
     NM_LINK_TYPE_BRIDGE,
     NM_LINK_TYPE_BOND,